@@ -72,7 +72,12 @@ class CacheFilter(wsgi.Middleware):
         if not image_meta['size']:
             # override image size metadata with the actual cached
             # file size, see LP Bug #900959
-            image_meta['size'] = self.cache.get_image_size(image_meta['id'])
+            if not isinstance(image_meta, policy.ImageTarget):
+                image_meta['size'] = self.cache.get_image_size(
+                    image_meta['id'])
+            else:
+                image_meta.target.size = self.cache.get_image_size(
+                    image_meta['id'])
 
     @staticmethod
     def _match_request(request):
@@ -149,8 +154,17 @@ class CacheFilter(wsgi.Middleware):
 
         self._stash_request_info(request, image_id, method, version)
 
+        # Partial image download requests shall not be served from cache
+        # Bug: 1664709
+        # TODO(dharinic): If an image is already cached, add support to serve
+        # only the requested bytes (partial image download) from the cache.
+        if (request.headers.get('Content-Range') or
+                request.headers.get('Range')):
+            return None
+
         if request.method != 'GET' or not self.cache.is_cached(image_id):
             return None
+
         method = getattr(self, '_get_%s_image_metadata' % version)
         image_metadata = method(request, image_id)
 
@@ -255,6 +269,10 @@ class CacheFilter(wsgi.Middleware):
         if not 200 <= status_code < 300:
             return resp
 
+        # Note(dharinic): Bug: 1664709: Do not cache partial images.
+        if status_code == http.PARTIAL_CONTENT:
+            return resp
+
         try:
             (image_id, method, version) = self._fetch_request_info(
                 resp.request)
