@@ -33,7 +33,7 @@ CONF = cfg.CONF
 
 DEFAULT_RULES = policy.Rules.from_dict({
     'context_is_admin': 'role:admin',
-    'default': '@',
+    'default': 'role:admin',
     'manage_image_cache': 'role:admin',
 })
 
@@ -190,7 +190,6 @@ class ImageProxy(glance.domain.proxy.Image):
         return self.image.get_data(*args, **kwargs)
 
     def set_data(self, *args, **kwargs):
-        self.policy.enforce(self.context, 'upload_image', self.target)
         return self.image.set_data(*args, **kwargs)
 
 
