@@ -94,7 +94,18 @@ class ImagesController(object):
         executor_factory = self.gateway.get_task_executor_factory(req.context)
         task_repo = self.gateway.get_task_repo(req.context)
 
-        task_input = {'image_id': image_id}
+        task_input = {'image_id': image_id,
+                      'import_req': body}
+
+        import_method = body.get('method').get('name')
+        uri = body.get('method').get('uri')
+        if (import_method == 'web-download' and
+           not utils.validate_import_uri(uri)):
+                LOG.debug("URI for web-download does not pass filtering: %s",
+                          uri)
+                msg = (_("URI for web-download does not pass filtering: %s") %
+                       uri)
+                raise webob.exc.HTTPBadRequest(explanation=msg)
 
         try:
             import_task = task_factory.new_task(task_type='api_image_import',
@@ -107,6 +118,16 @@ class ImagesController(object):
         except exception.Forbidden as e:
             LOG.debug("User not permitted to create image import task.")
             raise webob.exc.HTTPForbidden(explanation=e.msg)
+        except exception.Conflict as e:
+            raise webob.exc.HTTPConflict(explanation=e.msg)
+        except exception.InvalidImageStatusTransition as e:
+            raise webob.exc.HTTPConflict(explanation=e.msg)
+        except ValueError as e:
+            LOG.debug("Cannot import data for image %(id)s: %(e)s",
+                      {'id': image_id,
+                       'e': encodeutils.exception_to_unicode(e)})
+            raise webob.exc.HTTPBadRequest(
+                explanation=encodeutils.exception_to_unicode(e))
 
         return image_id
 
@@ -265,6 +286,13 @@ class ImagesController(object):
         image_repo = self.gateway.get_repo(req.context)
         try:
             image = image_repo.get(image_id)
+
+            # NOTE(abhishekk): If 'image-import' is supported and image status
+            # is uploading then delete image data from the staging area.
+            if CONF.enable_image_import and image.status == 'uploading':
+                file_path = str(CONF.node_staging_uri + '/' + image.image_id)
+                self.store_api.delete_from_backend(file_path)
+
             image.delete()
             image_repo.remove(image)
         except (glance_store.Forbidden, exception.Forbidden) as e:
@@ -443,6 +471,15 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
                     image[key] = properties.pop(key)
             except KeyError:
                 pass
+
+        # NOTE(abhishekk): Check if custom property key name is less than 255
+        # characters. Reference LP #1737952
+        for key in properties:
+            if len(key) > 255:
+                msg = (_("Custom property should not be greater than 255 "
+                         "characters."))
+                raise webob.exc.HTTPBadRequest(explanation=msg)
+
         return dict(image=image, extra_properties=properties, tags=tags)
 
     def _get_change_operation_d10(self, raw_change):
@@ -780,7 +817,7 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
         except KeyError:
             msg = _("Import request requires a 'name' field.")
             raise webob.exc.HTTPBadRequest(explanation=msg)
-        if method_name != 'glance-direct':
+        if method_name not in ['glance-direct', 'web-download']:
             msg = _("Unknown import method name '%s'.") % method_name
             raise webob.exc.HTTPBadRequest(explanation=msg)
 
@@ -838,8 +875,8 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
                     # image.locations is None to indicate it's allowed to show
                     # locations but it's just non-existent.
                     image_view['locations'] = []
-                    LOG.debug("There is not available location "
-                              "for image %s", image.image_id)
+                    LOG.debug("The 'locations' list of image %s is empty",
+                              image.image_id)
 
             if CONF.show_image_direct_url:
                 locations = _get_image_locations(image)
@@ -848,8 +885,9 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
                     l = location_strategy.choose_best_location(locations)
                     image_view['direct_url'] = l['url']
                 else:
-                    LOG.debug("There is not available location "
-                              "for image %s", image.image_id)
+                    LOG.debug("The 'locations' list of image %s is empty, "
+                              "not including 'direct_url' in response",
+                              image.image_id)
 
             image_view['tags'] = list(image.tags)
             image_view['self'] = self._get_image_href(image)
@@ -864,12 +902,15 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
         response.status_int = http.CREATED
         self.show(response, image)
         response.location = self._get_image_href(image)
-        # TODO(jokke): make this configurable when swift-local is implemented
-        # and remove the if statement with the config option.
+        # TODO(rosmaita): remove the outer 'if' statement when the
+        # enable_image_import config option is removed
         if CONF.enable_image_import:
-            import_methods = ("OpenStack-image-import-methods",
-                              "glance-direct")
-            response.headerlist.append(import_methods)
+            # according to RFC7230, headers should not have empty fields
+            # see http://httpwg.org/specs/rfc7230.html#field.components
+            if CONF.enabled_import_methods:
+                import_methods = ("OpenStack-image-import-methods",
+                                  ','.join(CONF.enabled_import_methods))
+                response.headerlist.append(import_methods)
 
     def show(self, response, image):
         image_view = self._format_image(image)
