@@ -23,6 +23,8 @@ from taskflow.patterns import linear_flow as lf
 from taskflow import retry
 from taskflow import task
 
+import glance.async.flows._internal_plugins as internal_plugins
+import glance.async.flows.plugins as import_plugins
 from glance.common import exception
 from glance.common.scripts.image_import import main as image_import
 from glance.common.scripts import utils as script_utils
@@ -35,9 +37,42 @@ LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
 
+api_import_opts = [
+    cfg.ListOpt('image_import_plugins',
+                item_type=cfg.types.String(quotes=True),
+                bounds=True,
+                sample_default='[no_op]',
+                default=[],
+                help=_("""
+Image import plugins to be enabled for task processing.
+
+Provide list of strings reflecting to the task Objects
+that should be included to the Image Import flow. The
+task objects needs to be defined in the 'glance/async/
+flows/plugins/*' and may be implemented by OpenStack
+Glance project team, deployer or 3rd party.
+
+By default no plugins are enabled and to take advantage
+of the plugin model the list of plugins must be set
+explicitly in the glance-image-import.conf file.
+
+The allowed values for this option is comma separated
+list of object names in between ``[`` and ``]``.
+
+Possible values:
+    * no_op (only logs debug level message that the
+      plugin has been executed)
+    * Any provided Task object name to be included
+      in to the flow.
+""")),
+]
+
+CONF.register_opts(api_import_opts, group='image_import_opts')
+
 # TODO(jokke): We should refactor the task implementations so that we do not
 # need to duplicate what we have already for example in base_import.py.
 
+
 class _DeleteFromFS(task.Task):
 
     def __init__(self, task_id, task_type):
@@ -139,63 +174,6 @@ class _ImportToStore(task.Task):
         :param image_id: Glance Image ID
         :param file_path: path to the image file
         """
-        # NOTE(flaper87): There are a couple of interesting bits in the
-        # interaction between this task and the `_ImportToFS` one. I'll try
-        # to cover them in this comment.
-        #
-        # NOTE(jokke): We do not have _ImportToFS currently in this flow but
-        # I will leave Flavio's comments here as we will utilize it or fork
-        # of it after MVP.
-        #
-        # NOTE(flaper87):
-        # `_ImportToFS` downloads the image to a dedicated `work_dir` which
-        # needs to be configured in advance (please refer to the config option
-        # docs for more info). The motivation behind this is also explained in
-        # the `_ImportToFS.execute` method.
-        #
-        # Due to the fact that we have an `_ImportToFS` task which downloads
-        # the image data already, we need to be as smart as we can in this task
-        # to avoid downloading the data several times and reducing the copy or
-        # write times. There are several scenarios where the interaction
-        # between this task and `_ImportToFS` could be improved. All these
-        # scenarios assume the `_ImportToFS` task has been executed before
-        # and/or in a more abstract scenario, that `file_path` is being
-        # provided.
-        #
-        # Scenario 1: FS Store is Remote, introspection enabled,
-        # conversion disabled
-        #
-        # In this scenario, the user would benefit from having the scratch path
-        # being the same path as the fs store. Only one write would happen and
-        # an extra read will happen in order to introspect the image. Note that
-        # this read is just for the image headers and not the entire file.
-        #
-        # Scenario 2: FS Store is remote, introspection enabled,
-        # conversion enabled
-        #
-        # In this scenario, the user would benefit from having a *local* store
-        # into which the image can be converted. This will require downloading
-        # the image locally, converting it and then copying the converted image
-        # to the remote store.
-        #
-        # Scenario 3: FS Store is local, introspection enabled,
-        # conversion disabled
-        # Scenario 4: FS Store is local, introspection enabled,
-        # conversion enabled
-        #
-        # In both these scenarios the user shouldn't care if the FS
-        # store path and the work dir are the same, therefore probably
-        # benefit, about the scratch path and the FS store being the
-        # same from a performance perspective. Space wise, regardless
-        # of the scenario, the user will have to account for it in
-        # advance.
-        #
-        # Lets get to it and identify the different scenarios in the
-        # implementation
-        image = self.image_repo.get(self.image_id)
-        image.status = 'importing'
-        self.image_repo.save(image)
-
         # NOTE(flaper87): Let's dance... and fall
         #
         # Unfortunatelly, because of the way our domain layers work and
@@ -236,6 +214,7 @@ class _ImportToStore(task.Task):
         # NOTE(jokke): The different options here are kind of pointless as we
         # will need the file path anyways for our delete workflow for now.
         # For future proofing keeping this as is.
+        image = self.image_repo.get(self.image_id)
         image_import.set_image_data(image, file_path or self.uri, self.task_id)
 
         # NOTE(flaper87): We need to save the image again after the locations
@@ -325,24 +304,35 @@ def get_flow(**kwargs):
     task_repo = kwargs.get('task_repo')
     image_repo = kwargs.get('image_repo')
     image_id = kwargs.get('image_id')
-    uri = kwargs.get('uri')
+    import_method = kwargs.get('import_req')['method']['name']
+    uri = kwargs.get('import_req')['method'].get('uri')
 
-    if not uri:
+    if not uri and import_method == 'glance-direct':
         separator = ''
         if not CONF.node_staging_uri.endswith('/'):
             separator = '/'
         uri = separator.join((CONF.node_staging_uri, str(image_id)))
 
     flow = lf.Flow(task_type, retry=retry.AlwaysRevert())
-    flow.add(_VerifyStaging(task_id, task_type, task_repo, uri))
 
-    # TODO(jokke): For the pluggable tasks like image verification or
-    # image conversion we need to implement the plugin logic here.
+    if import_method == 'web-download':
+        downloadToStaging = internal_plugins.get_import_plugin(**kwargs)
+        flow.add(downloadToStaging)
+        if not CONF.node_staging_uri.endswith('/'):
+            separator = '/'
+        file_uri = separator.join((CONF.node_staging_uri, str(image_id)))
+    else:
+        file_uri = uri
+
+    flow.add(_VerifyStaging(task_id, task_type, task_repo, file_uri))
+
+    for plugin in import_plugins.get_import_plugins(**kwargs):
+        flow.add(plugin)
 
     import_to_store = _ImportToStore(task_id,
                                      task_type,
                                      image_repo,
-                                     uri,
+                                     file_uri,
                                      image_id)
     flow.add(import_to_store)
 
@@ -361,4 +351,9 @@ def get_flow(**kwargs):
                                   image_id)
     flow.add(complete_task)
 
+    image = image_repo.get(image_id)
+    from_state = image.status
+    image.status = 'importing'
+    image_repo.save(image, from_state=from_state)
+
     return flow
