@@ -14,17 +14,17 @@
 #    under the License.
 
 import json
-import logging
 
 from oslo_concurrency import processutils as putils
+from oslo_log import log as logging
+from oslo_utils import encodeutils
 from oslo_utils import excutils
 from taskflow.patterns import linear_flow as lf
 
 from glance.async import utils
-from glance import i18n
+from glance.i18n import _LE
 
 
-_LE = i18n._LE
 LOG = logging.getLogger(__name__)
 
 
@@ -48,6 +48,7 @@ class _Introspect(utils.OptionalTask):
         try:
             stdout, stderr = putils.trycmd('qemu-img', 'info',
                                            '--output=json', file_path,
+                                           prlimit=utils.QEMU_IMG_PROC_LIMITS,
                                            log_errors=putils.LOG_ALL_ERRORS)
         except OSError as exc:
             # NOTE(flaper87): errno == 2 means the executable file
@@ -56,10 +57,11 @@ class _Introspect(utils.OptionalTask):
             # tasks.
             if exc.errno != 2:
                 with excutils.save_and_reraise_exception():
-                    msg = (_LE('Failed to execute introspection '
-                               '%(task_id)s: %(exc)s') %
-                           {'task_id': self.task_id, 'exc': exc.message})
-                    LOG.error(msg)
+                    exc_message = encodeutils.exception_to_unicode(exc)
+                    msg = _LE('Failed to execute introspection '
+                              '%(task_id)s: %(exc)s')
+                    LOG.error(msg, {'task_id': self.task_id,
+                                    'exc': exc_message})
             return
 
         if stderr:
@@ -70,7 +72,7 @@ class _Introspect(utils.OptionalTask):
         new_image.virtual_size = metadata.get('virtual-size', 0)
         new_image.disk_format = metadata.get('format')
         self.image_repo.save(new_image)
-        LOG.debug("%(task_id)s: Introspection successful: %(file)s" %
+        LOG.debug("%(task_id)s: Introspection successful: %(file)s",
                   {'task_id': self.task_id, 'file': file_path})
         return new_image
 
@@ -87,7 +89,7 @@ def get_flow(**kwargs):
     task_type = kwargs.get('task_type')
     image_repo = kwargs.get('image_repo')
 
-    LOG.debug("Flow: %(task_type)s with ID %(id)s on %(repo)s" %
+    LOG.debug("Flow: %(task_type)s with ID %(id)s on %(repo)s",
               {'task_type': task_type, 'id': task_id, 'repo': image_repo})
 
     return lf.Flow(task_type).add(
