@@ -128,6 +128,7 @@ class TaskExecutor(glance.async.TaskExecutor):
                 kwds['uri'] = uri
             if task.type == 'api_image_import':
                 kwds['image_id'] = task_input['image_id']
+                kwds['import_req'] = task_input['import_req']
             return driver.DriverManager('glance.flows', task.type,
                                         invoke_on_load=True,
                                         invoke_kwds=kwds).driver
@@ -170,6 +171,9 @@ class TaskExecutor(glance.async.TaskExecutor):
                 max_workers=CONF.taskflow_executor.max_workers)
             with llistener.DynamicLoggingListener(engine, log=LOG):
                 engine.run()
+        except exception.UploadException as exc:
+            task.fail(encodeutils.exception_to_unicode(exc))
+            self.task_repo.save(task)
         except Exception as exc:
             with excutils.save_and_reraise_exception():
                 LOG.error(_LE('Failed to execute task %(task_id)s: %(exc)s') %
