@@ -249,6 +249,14 @@ Related options:
     # glance/tests/functional/v2/test_images.py
     cfg.StrOpt('data_api',
                default='glance.db.sqlalchemy.api',
+                       deprecated_for_removal=True,
+                       deprecated_since="Queens",
+                       deprecated_reason=_("""
+Glance registry service is deprecated for removal.
+
+More information can be found from the spec:
+http://specs.openstack.org/openstack/glance-specs/specs/queens/approved/glance/deprecate-registry.html
+"""),
                help=_("""
 Python module path of data access API.
 
@@ -558,6 +566,14 @@ Related options:
 """)),
     cfg.BoolOpt('enable_v2_registry',
                 default=True,
+                deprecated_for_removal=True,
+                deprecated_since="Queens",
+                deprecated_reason=_("""
+Glance registry service is deprecated for removal.
+
+More information can be found from the spec:
+http://specs.openstack.org/openstack/glance-specs/specs/queens/approved/glance/deprecate-registry.html
+"""),
                 help=_("""
 Deploy the v2 API Registry service.
 
@@ -688,7 +704,7 @@ Related options:
 
 """)),
     cfg.BoolOpt('enable_image_import',
-                default=False,
+                default=True,
                 deprecated_for_removal=True,
                 deprecated_reason=_("""
 This option is deprecated for removal in Rocky.
@@ -705,11 +721,23 @@ Import, it's disabled per default in Pike, enabled per
 default in Queens and removed in Rocky. This allows Glance to
 operate with previous version configs upon upgrade.
 
-Setting this option to True will enable the endpoints related
+Setting this option to False will disable the endpoints related
 to Image Import Refactoring work.
 
 Related options:
-    * [DEFUALT]/node_staging_uri""")),
+    * [DEFAULT]/node_staging_uri""")),
+    cfg.ListOpt('enabled_import_methods',
+                item_type=cfg.types.String(quotes=True),
+                bounds=True,
+                default=['glance-direct', 'web-download'],
+                help=_("""
+List of enabled Image Import Methods
+
+Both 'glance-direct' and 'web-download' are enabled by default.
+
+Related options:
+    * [DEFAULT]/node_staging_uri
+    * [DEFAULT]/enable_image_import""")),
 ]
 
 CONF = cfg.CONF
@@ -766,7 +794,7 @@ def _get_deployment_config_file():
     path = CONF.paste_deploy.config_file
     if not path:
         path = _get_paste_config_path()
-    if not path:
+    if not path or not (os.path.isfile(os.path.abspath(path))):
         msg = _("Unable to locate paste config file for %s.") % CONF.prog
         raise RuntimeError(msg)
     return os.path.abspath(path)
