@@ -28,6 +28,7 @@ from oslo_config import cfg
 from oslo_db import exception as db_exception
 from oslo_db.sqlalchemy import session
 from oslo_log import log as logging
+from oslo_utils import excutils
 import osprofiler.sqlalchemy
 from retrying import retry
 import six
@@ -43,7 +44,6 @@ import sqlalchemy.sql as sa_sql
 from glance.common import exception
 from glance.common import timeutils
 from glance.common import utils
-from glance.db.sqlalchemy import glare
 from glance.db.sqlalchemy.metadef_api import (resource_type
                                               as metadef_resource_type_api)
 from glance.db.sqlalchemy.metadef_api import (resource_type_association
@@ -53,16 +53,15 @@ from glance.db.sqlalchemy.metadef_api import object as metadef_object_api
 from glance.db.sqlalchemy.metadef_api import property as metadef_property_api
 from glance.db.sqlalchemy.metadef_api import tag as metadef_tag_api
 from glance.db.sqlalchemy import models
-from glance import glare as ga
-from glance.i18n import _, _LW, _LI
+from glance.db import utils as db_utils
+from glance.i18n import _, _LW, _LI, _LE
 
-BASE = models.BASE
 sa_logger = None
 LOG = logging.getLogger(__name__)
 
 
 STATUSES = ['active', 'saving', 'queued', 'killed', 'pending_delete',
-            'deleted', 'deactivated']
+            'deleted', 'deactivated', 'importing', 'uploading']
 
 CONF = cfg.CONF
 CONF.import_group("profiler", "glance.common.wsgi")
@@ -134,28 +133,35 @@ def _check_mutate_authorization(context, image_ref):
     if not is_image_mutable(context, image_ref):
         LOG.warn(_LW("Attempted to modify image user did not own."))
         msg = _("You do not own this image")
-        if image_ref.is_public:
-            exc_class = exception.ForbiddenPublicImage
-        else:
+        if image_ref.visibility in ['private', 'shared']:
             exc_class = exception.Forbidden
+        else:
+            # 'public', or 'community'
+            exc_class = exception.ForbiddenPublicImage
 
         raise exc_class(msg)
 
 
-def image_create(context, values):
+def image_create(context, values, v1_mode=False):
     """Create an image from the values dictionary."""
-    return _image_update(context, values, None, purge_props=False)
+    image = _image_update(context, values, None, purge_props=False)
+    if v1_mode:
+        image = db_utils.mutate_image_dict_to_v1(image)
+    return image
 
 
 def image_update(context, image_id, values, purge_props=False,
-                 from_state=None):
+                 from_state=None, v1_mode=False):
     """
     Set the given properties on an image and update it.
 
     :raises: ImageNotFound if image does not exist.
     """
-    return _image_update(context, values, image_id, purge_props,
-                         from_state=from_state)
+    image = _image_update(context, values, image_id, purge_props,
+                          from_state=from_state)
+    if v1_mode:
+        image = db_utils.mutate_image_dict_to_v1(image)
+    return image
 
 
 @retry(retry_on_exception=_retry_on_deadlock, wait_fixed=500,
@@ -199,7 +205,7 @@ def _normalize_locations(context, image, force_show_deleted=False):
     if force_show_deleted:
         locations = image['locations']
     else:
-        locations = filter(lambda x: not x.deleted, image['locations'])
+        locations = [x for x in image['locations'] if not x.deleted]
     image['locations'] = [{'id': loc['id'],
                            'url': loc['value'],
                            'metadata': loc['meta_data'],
@@ -209,16 +215,19 @@ def _normalize_locations(context, image, force_show_deleted=False):
 
 
 def _normalize_tags(image):
-    undeleted_tags = filter(lambda x: not x.deleted, image['tags'])
+    undeleted_tags = [x for x in image['tags'] if not x.deleted]
     image['tags'] = [tag['value'] for tag in undeleted_tags]
     return image
 
 
-def image_get(context, image_id, session=None, force_show_deleted=False):
+def image_get(context, image_id, session=None, force_show_deleted=False,
+              v1_mode=False):
     image = _image_get(context, image_id, session=session,
                        force_show_deleted=force_show_deleted)
     image = _normalize_locations(context, image.to_dict(),
                                  force_show_deleted=force_show_deleted)
+    if v1_mode:
+        image = db_utils.mutate_image_dict_to_v1(image)
     return image
 
 
@@ -283,33 +292,7 @@ def is_image_mutable(context, image):
 
 def is_image_visible(context, image, status=None):
     """Return True if the image is visible in this context."""
-    # Is admin == image visible
-    if context.is_admin:
-        return True
-
-    # No owner == image visible
-    if image['owner'] is None:
-        return True
-
-    # Image is_public == image visible
-    if image['is_public']:
-        return True
-
-    # Perform tests based on whether we have an owner
-    if context.owner is not None:
-        if context.owner == image['owner']:
-            return True
-
-        # Figure out if this image is shared with that tenant
-        members = image_member_find(context,
-                                    image_id=image['id'],
-                                    member=context.owner,
-                                    status=status)
-        if members:
-            return True
-
-    # Private image
-    return False
+    return db_utils.is_image_visible(context, image, image_member_find, status)
 
 
 def _get_default_column_value(column_type):
@@ -457,18 +440,15 @@ def _make_conditions_from_filters(filters, is_public=None):
     tag_conditions = []
 
     if is_public is not None:
-        image_conditions.append(models.Image.is_public == is_public)
+        if is_public:
+            image_conditions.append(models.Image.visibility == 'public')
+        else:
+            image_conditions.append(models.Image.visibility != 'public')
 
     if 'checksum' in filters:
         checksum = filters.pop('checksum')
         image_conditions.append(models.Image.checksum == checksum)
 
-    if 'is_public' in filters:
-        key = 'is_public'
-        value = filters.pop('is_public')
-        prop_filters = _make_image_property_condition(key=key, value=value)
-        prop_conditions.append(prop_filters)
-
     for (k, v) in filters.pop('properties', {}).items():
         prop_filters = _make_image_property_condition(key=k, value=v)
         prop_conditions.append(prop_filters)
@@ -572,6 +552,7 @@ def _select_images_query(context, image_conditions, admin_as_user,
         models.Image.members).filter(img_conditional_clause)
     if regular_user:
         member_filters = [models.ImageMember.deleted == False]
+        member_filters.extend([models.Image.visibility == 'shared'])
         if context.owner is not None:
             member_filters.extend([models.ImageMember.member == context.owner])
             if member_status != 'all':
@@ -579,14 +560,13 @@ def _select_images_query(context, image_conditions, admin_as_user,
                     models.ImageMember.status == member_status])
         query_member = query_member.filter(sa_sql.and_(*member_filters))
 
-    # NOTE(venkatesh) if the 'visibility' is set to 'shared', we just
-    # query the image members table. No union is required.
-    if visibility is not None and visibility == 'shared':
-        return query_member
-
     query_image = session.query(models.Image).filter(img_conditional_clause)
     if regular_user:
-        query_image = query_image.filter(models.Image.is_public == True)
+        visibility_filters = [
+            models.Image.visibility == 'public',
+            models.Image.visibility == 'community',
+        ]
+        query_image = query_image .filter(sa_sql.or_(*visibility_filters))
         query_image_owner = None
         if context.owner is not None:
             query_image_owner = session.query(models.Image).filter(
@@ -605,7 +585,7 @@ def _select_images_query(context, image_conditions, admin_as_user,
 def image_get_all(context, filters=None, marker=None, limit=None,
                   sort_key=None, sort_dir=None,
                   member_status='accepted', is_public=None,
-                  admin_as_user=False, return_tag=False):
+                  admin_as_user=False, return_tag=False, v1_mode=False):
     """
     Get all images that match zero or more filters.
 
@@ -626,6 +606,8 @@ def image_get_all(context, filters=None, marker=None, limit=None,
     :param return_tag: To indicates whether image entry in result includes it
                        relevant tag entries. This could improve upper-layer
                        query performance, to prevent using separated calls
+    :param v1_mode: If true, mutates the 'visibility' value of each image
+                    into the v1-compatible field 'is_public'
     """
     sort_key = ['created_at'] if not sort_key else sort_key
 
@@ -651,12 +633,22 @@ def image_get_all(context, filters=None, marker=None, limit=None,
                                  admin_as_user,
                                  member_status,
                                  visibility)
-
     if visibility is not None:
-        if visibility == 'public':
-            query = query.filter(models.Image.is_public == True)
-        elif visibility == 'private':
-            query = query.filter(models.Image.is_public == False)
+        # with a visibility, we always and only include images with that
+        # visibility
+        query = query.filter(models.Image.visibility == visibility)
+    elif context.owner is None:
+        # without either a visibility or an owner, we never include
+        # 'community' images
+        query = query.filter(models.Image.visibility != 'community')
+    else:
+        # without a visibility and with an owner, we only want to include
+        # 'community' images if and only if they are owned by this owner
+        community_filters = [
+            models.Image.owner == context.owner,
+            models.Image.visibility != 'community',
+        ]
+        query = query.filter(sa_sql.or_(*community_filters))
 
     if prop_cond:
         for prop_condition in prop_cond:
@@ -698,6 +690,8 @@ def image_get_all(context, filters=None, marker=None, limit=None,
                                           force_show_deleted=showing_deleted)
         if return_tag:
             image_dict = _normalize_tags(image_dict)
+        if v1_mode:
+            image_dict = db_utils.mutate_image_dict_to_v1(image_dict)
         images.append(image_dict)
     return images
 
@@ -789,7 +783,7 @@ def _image_update(context, values, image_id, purge_props=False,
 
         location_data = values.pop('locations', None)
 
-        new_status = values.get('status', None)
+        new_status = values.get('status')
         if image_id:
             image_ref = _image_get(context, image_id, session=session)
             current = image_ref.status
@@ -805,10 +799,11 @@ def _image_update(context, values, image_id, purge_props=False,
             if 'min_disk' in values:
                 values['min_disk'] = int(values['min_disk'] or 0)
 
-            values['is_public'] = bool(values.get('is_public', False))
             values['protected'] = bool(values.get('protected', False))
             image_ref = models.Image()
 
+        values = db_utils.ensure_image_dict_v2_compliant(values)
+
         # Need to canonicalize ownership
         if 'owner' in values and not values['owner']:
             values['owner'] = None
@@ -1077,6 +1072,7 @@ def _image_property_delete_all(context, image_id, delete_time=None,
     return props_updated_count
 
 
+@utils.no_4byte_params
 def image_member_create(context, values, session=None):
     """Create an ImageMember object."""
     memb_ref = models.ImageMember()
@@ -1303,7 +1299,7 @@ def purge_deleted_rows(context, age_in_days, max_rows, session=None):
             continue
         if hasattr(model_class, 'deleted'):
             tables.append(model_class.__tablename__)
-    # get rid of FX constraints
+    # get rid of FK constraints
     for tbl in ('images', 'tasks'):
         try:
             tables.remove(tbl)
@@ -1329,8 +1325,14 @@ def purge_deleted_rows(context, age_in_days, max_rows, session=None):
 
         delete_statement = DeleteFromSelect(tab, query_delete, column)
 
-        with session.begin():
-            result = session.execute(delete_statement)
+        try:
+            with session.begin():
+                result = session.execute(delete_statement)
+        except db_exception.DBReferenceError as ex:
+            with excutils.save_and_reraise_exception():
+                LOG.error(_LE('DBError detected when purging from '
+                          "%(tablename)s: %(error)s"),
+                          {'tablename': tbl, 'error': six.text_type(ex)})
 
         rows = result.rowcount
         LOG.info(_LI('Deleted %(rows)d row(s) from table %(tbl)s'),
@@ -1413,7 +1415,7 @@ def task_create(context, values, session=None):
 
 def _pop_task_info_values(values):
     task_info_values = {}
-    for k, v in values.items():
+    for k, v in list(values.items()):
         if k in ['input', 'result', 'message']:
             values.pop(k)
             task_info_values[k] = v
@@ -1467,9 +1469,9 @@ def _task_soft_delete(context, session=None):
     query = session.query(models.Task)
 
     query = (query.filter(models.Task.owner == context.owner)
-                  .filter_by(deleted=0)
+                  .filter_by(deleted=False)
                   .filter(expires_at <= timeutils.utcnow()))
-    values = {'deleted': 1, 'deleted_at': timeutils.utcnow()}
+    values = {'deleted': True, 'deleted_at': timeutils.utcnow()}
 
     with session.begin():
         query.update(values)
@@ -1877,58 +1879,3 @@ def metadef_tag_count(context, namespace_name, session=None):
     """Get count of tags for a namespace, raise if ns doesn't exist."""
     session = session or get_session()
     return metadef_tag_api.count(context, namespace_name, session)
-
-
-def artifact_create(context, values, type_name,
-                    type_version=None, session=None):
-    session = session or get_session()
-    artifact = glare.create(context, values, session, type_name,
-                            type_version)
-    return artifact
-
-
-def artifact_delete(context, artifact_id, type_name,
-                    type_version=None, session=None):
-    session = session or get_session()
-    artifact = glare.delete(context, artifact_id, session, type_name,
-                            type_version)
-    return artifact
-
-
-def artifact_update(context, values, artifact_id, type_name,
-                    type_version=None, session=None):
-    session = session or get_session()
-    artifact = glare.update(context, values, artifact_id, session,
-                            type_name, type_version)
-    return artifact
-
-
-def artifact_get(context, artifact_id,
-                 type_name=None,
-                 type_version=None,
-                 show_level=ga.Showlevel.BASIC,
-                 session=None):
-    session = session or get_session()
-    return glare.get(context, artifact_id, session, type_name,
-                     type_version, show_level)
-
-
-def artifact_publish(context,
-                     artifact_id,
-                     type_name,
-                     type_version=None,
-                     session=None):
-    session = session or get_session()
-    return glare.publish(context,
-                         artifact_id,
-                         session,
-                         type_name,
-                         type_version)
-
-
-def artifact_get_all(context, marker=None, limit=None, sort_keys=None,
-                     sort_dirs=None, filters=None,
-                     show_level=ga.Showlevel.NONE, session=None):
-    session = session or get_session()
-    return glare.get_all(context, session, marker, limit, sort_keys,
-                         sort_dirs, filters, show_level)
