@@ -26,24 +26,37 @@ import time
 
 from eventlet import sleep
 from eventlet import timeout
+from oslo_concurrency import lockutils
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
+from oslo_utils import fileutils
 
 from glance.common import exception
-from glance import i18n
+from glance.i18n import _, _LE, _LI, _LW
 from glance.image_cache.drivers import base
 
 LOG = logging.getLogger(__name__)
-_ = i18n._
-_LE = i18n._LE
-_LI = i18n._LI
-_LW = i18n._LW
 
 sqlite_opts = [
     cfg.StrOpt('image_cache_sqlite_db', default='cache.db',
-               help=_('The path to the sqlite file database that will be '
-                      'used for image cache management.')),
+               help=_("""
+The relative path to sqlite file database that will be used for image cache
+management.
+
+This is a relative path to the sqlite file database that tracks the age and
+usage statistics of image cache. The path is relative to image cache base
+directory, specified by the configuration option ``image_cache_dir``.
+
+This is a lightweight database with just one table.
+
+Possible values:
+    * A valid relative path to sqlite file database
+
+Related options:
+    * ``image_cache_dir``
+
+""")),
 ]
 
 CONF = cfg.CONF
@@ -108,26 +121,32 @@ class Driver(base.Driver):
     def initialize_db(self):
         db = CONF.image_cache_sqlite_db
         self.db_path = os.path.join(self.base_dir, db)
-        try:
-            conn = sqlite3.connect(self.db_path, check_same_thread=False,
-                                   factory=SqliteConnection)
-            conn.executescript("""
-                CREATE TABLE IF NOT EXISTS cached_images (
-                    image_id TEXT PRIMARY KEY,
-                    last_accessed REAL DEFAULT 0.0,
-                    last_modified REAL DEFAULT 0.0,
-                    size INTEGER DEFAULT 0,
-                    hits INTEGER DEFAULT 0,
-                    checksum TEXT
-                );
-            """)
-            conn.close()
-        except sqlite3.DatabaseError as e:
-            msg = _("Failed to initialize the image cache database. "
-                    "Got error: %s") % e
-            LOG.error(msg)
-            raise exception.BadDriverConfiguration(driver_name='sqlite',
-                                                   reason=msg)
+        lockutils.set_defaults(self.base_dir)
+
+        @lockutils.synchronized('image_cache_db_init', external=True)
+        def create_db():
+            try:
+                conn = sqlite3.connect(self.db_path, check_same_thread=False,
+                                       factory=SqliteConnection)
+                conn.executescript("""
+                    CREATE TABLE IF NOT EXISTS cached_images (
+                        image_id TEXT PRIMARY KEY,
+                        last_accessed REAL DEFAULT 0.0,
+                        last_modified REAL DEFAULT 0.0,
+                        size INTEGER DEFAULT 0,
+                        hits INTEGER DEFAULT 0,
+                        checksum TEXT
+                    );
+                """)
+                conn.close()
+            except sqlite3.DatabaseError as e:
+                msg = _("Failed to initialize the image cache database. "
+                        "Got error: %s") % e
+                LOG.error(msg)
+                raise exception.BadDriverConfiguration(driver_name='sqlite',
+                                                       reason=msg)
+
+        create_db()
 
     def get_cache_size(self):
         """
@@ -242,7 +261,7 @@ class Driver(base.Driver):
         """
         files = [f for f in self.get_cache_files(self.queue_dir)]
         for file in files:
-            os.unlink(file)
+            fileutils.delete_if_exists(file)
         return len(files)
 
     def delete_queued_image(self, image_id):
@@ -252,8 +271,7 @@ class Driver(base.Driver):
         :param image_id: Image ID
         """
         path = self.get_image_filepath(image_id, 'queue')
-        if os.path.exists(path):
-            os.unlink(path)
+        fileutils.delete_if_exists(path)
 
     def clean(self, stall_time=None):
         """
@@ -313,7 +331,8 @@ class Driver(base.Driver):
 
                 # Make sure that we "pop" the image from the queue...
                 if self.is_queued(image_id):
-                    os.unlink(self.get_image_filepath(image_id, 'queue'))
+                    fileutils.delete_if_exists(
+                        self.get_image_filepath(image_id, 'queue'))
 
                 filesize = os.path.getsize(final_path)
                 now = time.time()
@@ -410,19 +429,16 @@ class Driver(base.Driver):
         :param image_id: Image ID
         """
         if self.is_cached(image_id):
-            msg = _LI("Not queueing image '%s'. Already cached.") % image_id
-            LOG.info(msg)
+            LOG.info(_LI("Not queueing image '%s'. Already cached."), image_id)
             return False
 
         if self.is_being_cached(image_id):
-            msg = _LI("Not queueing image '%s'. Already being "
-                      "written to cache") % image_id
-            LOG.info(msg)
+            LOG.info(_LI("Not queueing image '%s'. Already being "
+                         "written to cache"), image_id)
             return False
 
         if self.is_queued(image_id):
-            msg = _LI("Not queueing image '%s'. Already queued.") % image_id
-            LOG.info(msg)
+            LOG.info(_LI("Not queueing image '%s'. Already queued."), image_id)
             return False
 
         path = self.get_image_filepath(image_id, 'queue')
@@ -438,8 +454,8 @@ class Driver(base.Driver):
         Removes any invalid cache entries
         """
         for path in self.get_cache_files(self.invalid_dir):
-            os.unlink(path)
-            LOG.info(_LI("Removed invalid cache file %s") % path)
+            fileutils.delete_if_exists(path)
+            LOG.info(_LI("Removed invalid cache file %s"), path)
 
     def delete_stalled_files(self, older_than):
         """
@@ -452,8 +468,8 @@ class Driver(base.Driver):
         for path in self.get_cache_files(self.incomplete_dir):
             if os.path.getmtime(path) < older_than:
                 try:
-                    os.unlink(path)
-                    LOG.info(_LI("Removed stalled cache file %s") % path)
+                    fileutils.delete_if_exists(path)
+                    LOG.info(_LI("Removed stalled cache file %s"), path)
                 except Exception as e:
                     msg = (_LW("Failed to delete file %(path)s. "
                                "Got error: %(e)s"),
@@ -488,9 +504,5 @@ class Driver(base.Driver):
 
 
 def delete_cached_file(path):
-    if os.path.exists(path):
-        LOG.debug("Deleting image cache file '%s'", path)
-        os.unlink(path)
-    else:
-        LOG.warn(_LW("Cached image file '%s' doesn't exist, unable to"
-                     " delete") % path)
+    LOG.debug("Deleting image cache file '%s'", path)
+    fileutils.delete_if_exists(path)
