@@ -17,6 +17,7 @@ import time
 
 import httplib2
 import psutil
+from six.moves import http_client
 # NOTE(jokke): simplified transition to py3, behaves like py2 xrange
 from six.moves import range
 
@@ -39,15 +40,19 @@ class TestMultiprocessing(functional.FunctionalTest):
         path = "http://%s:%d/v1/images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         self.assertEqual(b'{"images": []}', content)
         self.stop_servers()
 
     def _get_children(self):
         api_pid = self.api_server.process_pid
         process = psutil.Process(api_pid)
-
-        children = process.get_children()
+        try:
+            # psutils version >= 2
+            children = process.children()
+        except AttributeError:
+            # psutils version < 2
+            children = process.get_children()
         pids = [str(child.pid) for child in children]
         return pids
 
