@@ -15,10 +15,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-# NOTE(rosmaita): mriedem says this is needed for importing from fixtures,
-# and he's right!
-from __future__ import absolute_import
-
 import datetime
 import gettext
 import os
@@ -608,7 +604,7 @@ class ServerTest(test_utils.BaseTestCase):
                                                 socket_timeout=900)
 
     def test_number_of_workers(self):
-        """Ensure the default number of workers matches num cpus."""
+        """Ensure the number of workers matches num cpus limited to 8."""
         def pid():
             i = 1
             while True:
@@ -616,12 +612,30 @@ class ServerTest(test_utils.BaseTestCase):
                 yield i
 
         with mock.patch.object(os, 'fork') as mock_fork:
+            with mock.patch('oslo_concurrency.processutils.get_worker_count',
+                            return_value=4):
+                mock_fork.side_effect = pid
+                server = wsgi.Server()
+                server.configure = mock.Mock()
+                fake_application = "fake-application"
+                server.start(fake_application, None)
+                self.assertEqual(4, len(server.children))
+            with mock.patch('oslo_concurrency.processutils.get_worker_count',
+                            return_value=24):
+                mock_fork.side_effect = pid
+                server = wsgi.Server()
+                server.configure = mock.Mock()
+                fake_application = "fake-application"
+                server.start(fake_application, None)
+                self.assertEqual(8, len(server.children))
             mock_fork.side_effect = pid
             server = wsgi.Server()
             server.configure = mock.Mock()
             fake_application = "fake-application"
             server.start(fake_application, None)
-            self.assertEqual(processutils.get_worker_count(),
+            cpus = processutils.get_worker_count()
+            expected_workers = cpus if cpus < 8 else 8
+            self.assertEqual(expected_workers,
                              len(server.children))
 
 
@@ -742,3 +756,68 @@ class GetSocketTestCase(test_utils.BaseTestCase):
             'glance.common.wsgi.ssl.wrap_socket',
             lambda *x, **y: None))
         self.assertRaises(wsgi.socket.error, wsgi.get_socket, 1234)
+
+
+def _cleanup_uwsgi():
+    wsgi.uwsgi = None
+
+
+class Test_UwsgiChunkedFile(test_utils.BaseTestCase):
+
+    def test_read_no_data(self):
+        reader = wsgi._UWSGIChunkFile()
+        wsgi.uwsgi = mock.MagicMock()
+        self.addCleanup(_cleanup_uwsgi)
+
+        def fake_read():
+            return None
+
+        wsgi.uwsgi.chunked_read = fake_read
+        out = reader.read()
+        self.assertEqual(out, b'')
+
+    def test_read_data_no_length(self):
+        reader = wsgi._UWSGIChunkFile()
+        wsgi.uwsgi = mock.MagicMock()
+        self.addCleanup(_cleanup_uwsgi)
+
+        values = iter([b'a', b'b', b'c', None])
+
+        def fake_read():
+            return next(values)
+
+        wsgi.uwsgi.chunked_read = fake_read
+        out = reader.read()
+        self.assertEqual(out, b'abc')
+
+    def test_read_zero_length(self):
+        reader = wsgi._UWSGIChunkFile()
+        self.assertEqual(b'', reader.read(length=0))
+
+    def test_read_data_length(self):
+        reader = wsgi._UWSGIChunkFile()
+        wsgi.uwsgi = mock.MagicMock()
+        self.addCleanup(_cleanup_uwsgi)
+
+        values = iter([b'a', b'b', b'c', None])
+
+        def fake_read():
+            return next(values)
+
+        wsgi.uwsgi.chunked_read = fake_read
+        out = reader.read(length=2)
+        self.assertEqual(out, b'ab')
+
+    def test_read_data_negative_length(self):
+        reader = wsgi._UWSGIChunkFile()
+        wsgi.uwsgi = mock.MagicMock()
+        self.addCleanup(_cleanup_uwsgi)
+
+        values = iter([b'a', b'b', b'c', None])
+
+        def fake_read():
+            return next(values)
+
+        wsgi.uwsgi.chunked_read = fake_read
+        out = reader.read(length=-2)
+        self.assertEqual(out, b'abc')
