@@ -208,7 +208,6 @@ class TestPolicyEnforcerNoFile(base.IsolatedUnitTest):
         enforcer = glance.api.policy.Enforcer()
 
         context = glance.context.RequestContext(roles=[])
-        enforcer.enforce(context, 'get_image', {})
         self.assertRaises(exception.Forbidden,
                           enforcer.enforce, context, 'manage_image_cache', {})
 
@@ -226,7 +225,6 @@ class TestPolicyEnforcerNoFile(base.IsolatedUnitTest):
         enforcer = glance.api.policy.Enforcer()
 
         context = glance.context.RequestContext(roles=[])
-        enforcer.enforce(context, 'get_image', {})
         self.assertRaises(exception.Forbidden,
                           enforcer.enforce, context, 'manage_image_cache', {})
 
@@ -409,13 +407,6 @@ class TestImagePolicy(test_utils.BaseTestCase):
         self.policy.enforce.assert_called_once_with({}, "download_image",
                                                     target)
 
-    def test_image_set_data(self):
-        self.policy.enforce.side_effect = exception.Forbidden
-        image = glance.api.policy.ImageProxy(self.image_stub, {}, self.policy)
-        self.assertRaises(exception.Forbidden, image.set_data)
-        self.policy.enforce.assert_called_once_with({}, "upload_image",
-                                                    image.target)
-
 
 class TestMemberPolicy(test_utils.BaseTestCase):
     def setUp(self):
